# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.encoding.infrastructure.aws.aws_api import AwsApi
from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ips_api import StaticIpsApi
from bitmovin_api_sdk.encoding.infrastructure.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.infrastructure.gce.gce_api import GceApi
from bitmovin_api_sdk.encoding.infrastructure.akamai.akamai_api import AkamaiApi
from bitmovin_api_sdk.encoding.infrastructure.oci.oci_api import OciApi
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.prewarmed_encoder_pools_api import PrewarmedEncoderPoolsApi


class InfrastructureApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(InfrastructureApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.aws = AwsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.static_ips = StaticIpsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.azure = AzureApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gce = GceApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.akamai = AkamaiApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.oci = OciApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.prewarmed_encoder_pools = PrewarmedEncoderPoolsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_mov.progressive_mov_api import ProgressiveMovApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_mov.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_mov.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_mov.progressive_mov_muxing_list_query_params import ProgressiveMovMuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class StreamsLiveUpdateRequest(object):
    @poscheck_model
    def __init__(self,
                 title=None,
                 description=None,
                 poster_url=None,
                 domain_restriction_id=None):
        # type: (string_types, string_types, string_types, string_types) -> None

        self._title = None
        self._description = None
        self._poster_url = None
        self._domain_restriction_id = None
        self.discriminator = None

        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if poster_url is not None:
            self.poster_url = poster_url
        if domain_restriction_id is not None:
            self.domain_restriction_id = domain_restriction_id

    @property
    def openapi_types(self):
        types = {
            'title': 'string_types',
            'description': 'string_types',
            'poster_url': 'string_types',
            'domain_restriction_id': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'title': 'title',
            'description': 'description',
            'poster_url': 'posterUrl',
            'domain_restriction_id': 'domainRestrictionId'
        }
        return attributes

    @property
    def title(self):
        # type: () -> string_types
        """Gets the title of this StreamsLiveUpdateRequest.

        The new title of the stream

        :return: The title of this StreamsLiveUpdateRequest.
        :rtype: string_types
        """
        return self._title

    @title.setter
    def title(self, title):
        # type: (string_types) -> None
        """Sets the title of this StreamsLiveUpdateRequest.

        The new title of the stream

        :param title: The title of this StreamsLiveUpdateRequest.
        :type: string_types
        """

        if title is not None:
            if not isinstance(title, string_types):
                raise TypeError("Invalid type for `title`, type has to be `string_types`")

        self._title = title

    @property
    def description(self):
        # type: () -> string_types
        """Gets the description of this StreamsLiveUpdateRequest.

        The new description of the stream

        :return: The description of this StreamsLiveUpdateRequest.
        :rtype: string_types
        """
        return self._description

    @description.setter
    def description(self, description):
        # type: (string_types) -> None
        """Sets the description of this StreamsLiveUpdateRequest.

        The new description of the stream

        :param description: The description of this StreamsLiveUpdateRequest.
        :type: string_types
        """

        if description is not None:
            if not isinstance(description, string_types):
                raise TypeError("Invalid type for `description`, type has to be `string_types`")

        self._description = description

    @property
    def poster_url(self):
        # type: () -> string_types
        """Gets the poster_url of this StreamsLiveUpdateRequest.

        URL to hosted poster image

        :return: The poster_url of this StreamsLiveUpdateRequest.
        :rtype: string_types
        """
        return self._poster_url

    @poster_url.setter
    def poster_url(self, poster_url):
        # type: (string_types) -> None
        """Sets the poster_url of this StreamsLiveUpdateRequest.

        URL to hosted poster image

        :param poster_url: The poster_url of this StreamsLiveUpdateRequest.
        :type: string_types
        """

        if poster_url is not None:
            if not isinstance(poster_url, string_types):
                raise TypeError("Invalid type for `poster_url`, type has to be `string_types`")

        self._poster_url = poster_url

    @property
    def domain_restriction_id(self):
        # type: () -> string_types
        """Gets the domain_restriction_id of this StreamsLiveUpdateRequest.

        Id of the domain restriction config to use

        :return: The domain_restriction_id of this StreamsLiveUpdateRequest.
        :rtype: string_types
        """
        return self._domain_restriction_id

    @domain_restriction_id.setter
    def domain_restriction_id(self, domain_restriction_id):
        # type: (string_types) -> None
        """Sets the domain_restriction_id of this StreamsLiveUpdateRequest.

        Id of the domain restriction config to use

        :param domain_restriction_id: The domain_restriction_id of this StreamsLiveUpdateRequest.
        :type: string_types
        """

        if domain_restriction_id is not None:
            if not isinstance(domain_restriction_id, string_types):
                raise TypeError("Invalid type for `domain_restriction_id`, type has to be `string_types`")

        self._domain_restriction_id = domain_restriction_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamsLiveUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class PaginationResponse(object):
    @poscheck_model
    def __init__(self,
                 total_count=None,
                 offset=None,
                 limit=None,
                 previous=None,
                 next_=None,
                 items=None):
        # type: (int, int, int, string_types, string_types, list[object]) -> None

        self._total_count = None
        self._offset = None
        self._limit = None
        self._previous = None
        self._next = None
        self._items = list()
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if previous is not None:
            self.previous = previous
        if next_ is not None:
            self.next = next_
        if items is not None:
            self.items = items

    @property
    def openapi_types(self):
        types = {
            'total_count': 'int',
            'offset': 'int',
            'limit': 'int',
            'previous': 'string_types',
            'next': 'string_types',
            'items': 'list[object]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'total_count': 'totalCount',
            'offset': 'offset',
            'limit': 'limit',
            'previous': 'previous',
            'next': 'next',
            'items': 'items'
        }
        return attributes

    @property
    def total_count(self):
        # type: () -> int
        """Gets the total_count of this PaginationResponse.


        :return: The total_count of this PaginationResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        # type: (int) -> None
        """Sets the total_count of this PaginationResponse.


        :param total_count: The total_count of this PaginationResponse.
        :type: int
        """

        if total_count is not None:
            if not isinstance(total_count, int):
                raise TypeError("Invalid type for `total_count`, type has to be `int`")

        self._total_count = total_count

    @property
    def offset(self):
        # type: () -> int
        """Gets the offset of this PaginationResponse.


        :return: The offset of this PaginationResponse.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        # type: (int) -> None
        """Sets the offset of this PaginationResponse.


        :param offset: The offset of this PaginationResponse.
        :type: int
        """

        if offset is not None:
            if not isinstance(offset, int):
                raise TypeError("Invalid type for `offset`, type has to be `int`")

        self._offset = offset

    @property
    def limit(self):
        # type: () -> int
        """Gets the limit of this PaginationResponse.


        :return: The limit of this PaginationResponse.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        # type: (int) -> None
        """Sets the limit of this PaginationResponse.


        :param limit: The limit of this PaginationResponse.
        :type: int
        """

        if limit is not None:
            if not isinstance(limit, int):
                raise TypeError("Invalid type for `limit`, type has to be `int`")

        self._limit = limit

    @property
    def previous(self):
        # type: () -> string_types
        """Gets the previous of this PaginationResponse.


        :return: The previous of this PaginationResponse.
        :rtype: string_types
        """
        return self._previous

    @previous.setter
    def previous(self, previous):
        # type: (string_types) -> None
        """Sets the previous of this PaginationResponse.


        :param previous: The previous of this PaginationResponse.
        :type: string_types
        """

        if previous is not None:
            if not isinstance(previous, string_types):
                raise TypeError("Invalid type for `previous`, type has to be `string_types`")

        self._previous = previous

    @property
    def next(self):
        # type: () -> string_types
        """Gets the next of this PaginationResponse.


        :return: The next of this PaginationResponse.
        :rtype: string_types
        """
        return self._next

    @next.setter
    def next(self, next_):
        # type: (string_types) -> None
        """Sets the next of this PaginationResponse.


        :param next_: The next of this PaginationResponse.
        :type: string_types
        """

        if next_ is not None:
            if not isinstance(next_, string_types):
                raise TypeError("Invalid type for `next`, type has to be `string_types`")

        self._next = next_

    @property
    def items(self):
        # type: () -> list[object]
        """Gets the items of this PaginationResponse.


        :return: The items of this PaginationResponse.
        :rtype: list[object]
        """
        return self._items

    @items.setter
    def items(self, items):
        # type: (list) -> None
        """Sets the items of this PaginationResponse.


        :param items: The items of this PaginationResponse.
        :type: list[object]
        """

        if items is not None:
            if not isinstance(items, list):
                raise TypeError("Invalid type for `items`, type has to be `list[object]`")

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaginationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.live.stream_keys.stream_keys_api import StreamKeysApi
from bitmovin_api_sdk.encoding.live.standby_pools.standby_pools_api import StandbyPoolsApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.fmp4_muxing_information import Fmp4MuxingInformation
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class InformationApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(InformationApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, muxing_id, **kwargs):
        # type: (string_types, string_types, dict) -> Fmp4MuxingInformation
        """Fmp4 muxing Information

        :param encoding_id: ID of the Encoding.
        :type encoding_id: string_types, required
        :param muxing_id: ID of the Fmp4 muxing
        :type muxing_id: string_types, required
        :return: Fmp4 muxing Information
        :rtype: Fmp4MuxingInformation
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/fmp4/{muxing_id}/information',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=Fmp4MuxingInformation,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class ResetLiveManifestTimeShift(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 residual_period_in_seconds=None,
                 offset_in_seconds=None,
                 manifest_ids=None,
                 shift_progressive_muxing_start_position=None):
        # type: (string_types, float, float, list[string_types], bool) -> None
        super(ResetLiveManifestTimeShift, self).__init__(id_=id_)

        self._residual_period_in_seconds = None
        self._offset_in_seconds = None
        self._manifest_ids = list()
        self._shift_progressive_muxing_start_position = None
        self.discriminator = None

        if residual_period_in_seconds is not None:
            self.residual_period_in_seconds = residual_period_in_seconds
        if offset_in_seconds is not None:
            self.offset_in_seconds = offset_in_seconds
        if manifest_ids is not None:
            self.manifest_ids = manifest_ids
        if shift_progressive_muxing_start_position is not None:
            self.shift_progressive_muxing_start_position = shift_progressive_muxing_start_position

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ResetLiveManifestTimeShift, self), 'openapi_types'):
            types = getattr(super(ResetLiveManifestTimeShift, self), 'openapi_types')

        types.update({
            'residual_period_in_seconds': 'float',
            'offset_in_seconds': 'float',
            'manifest_ids': 'list[string_types]',
            'shift_progressive_muxing_start_position': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ResetLiveManifestTimeShift, self), 'attribute_map'):
            attributes = getattr(super(ResetLiveManifestTimeShift, self), 'attribute_map')

        attributes.update({
            'residual_period_in_seconds': 'residualPeriodInSeconds',
            'offset_in_seconds': 'offsetInSeconds',
            'manifest_ids': 'manifestIds',
            'shift_progressive_muxing_start_position': 'shiftProgressiveMuxingStartPosition'
        })
        return attributes

    @property
    def residual_period_in_seconds(self):
        # type: () -> float
        """Gets the residual_period_in_seconds of this ResetLiveManifestTimeShift.

        Determines how many seconds will be left in the manifest after segments are removed. If this is not set, all but one segment will be removed. 

        :return: The residual_period_in_seconds of this ResetLiveManifestTimeShift.
        :rtype: float
        """
        return self._residual_period_in_seconds

    @residual_period_in_seconds.setter
    def residual_period_in_seconds(self, residual_period_in_seconds):
        # type: (float) -> None
        """Sets the residual_period_in_seconds of this ResetLiveManifestTimeShift.

        Determines how many seconds will be left in the manifest after segments are removed. If this is not set, all but one segment will be removed. 

        :param residual_period_in_seconds: The residual_period_in_seconds of this ResetLiveManifestTimeShift.
        :type: float
        """

        if residual_period_in_seconds is not None:
            if not isinstance(residual_period_in_seconds, (float, int)):
                raise TypeError("Invalid type for `residual_period_in_seconds`, type has to be `float`")

        self._residual_period_in_seconds = residual_period_in_seconds

    @property
    def offset_in_seconds(self):
        # type: () -> float
        """Gets the offset_in_seconds of this ResetLiveManifestTimeShift.

        Offset in seconds from the start of the live event, defining the point from which all segments within that duration will be removed from the given manifests. E.g.: The segment length is 2 seconds and a timeshift of 120 seconds (2 minutes) is configured.  The manifest contains 60 segments with the last segment number being 80 (`segment_80.ts`).  This means the manifest contains `segment_20.ts` to `segment_80.ts` (timeshift of 2 minutes equals 60 segments in manifest) If you set `offsetInSeconds` to `120`, all segments below segment number 60 (`segment_60.ts`) will be removed. (`targetSegmentNumber = offsetInSeconds / segmentLength`) The manifests will then contain `segment_60.ts` to `segment_80.ts` *Note:* Only `offsetInSeconds` or `residualPeriodInSeconds` can be set. 

        :return: The offset_in_seconds of this ResetLiveManifestTimeShift.
        :rtype: float
        """
        return self._offset_in_seconds

    @offset_in_seconds.setter
    def offset_in_seconds(self, offset_in_seconds):
        # type: (float) -> None
        """Sets the offset_in_seconds of this ResetLiveManifestTimeShift.

        Offset in seconds from the start of the live event, defining the point from which all segments within that duration will be removed from the given manifests. E.g.: The segment length is 2 seconds and a timeshift of 120 seconds (2 minutes) is configured.  The manifest contains 60 segments with the last segment number being 80 (`segment_80.ts`).  This means the manifest contains `segment_20.ts` to `segment_80.ts` (timeshift of 2 minutes equals 60 segments in manifest) If you set `offsetInSeconds` to `120`, all segments below segment number 60 (`segment_60.ts`) will be removed. (`targetSegmentNumber = offsetInSeconds / segmentLength`) The manifests will then contain `segment_60.ts` to `segment_80.ts` *Note:* Only `offsetInSeconds` or `residualPeriodInSeconds` can be set. 

        :param offset_in_seconds: The offset_in_seconds of this ResetLiveManifestTimeShift.
        :type: float
        """

        if offset_in_seconds is not None:
            if not isinstance(offset_in_seconds, (float, int)):
                raise TypeError("Invalid type for `offset_in_seconds`, type has to be `float`")

        self._offset_in_seconds = offset_in_seconds

    @property
    def manifest_ids(self):
        # type: () -> list[string_types]
        """Gets the manifest_ids of this ResetLiveManifestTimeShift.

        The ids of the manifests to update. If this property is not set, all manifests tied to the encoding are updated.

        :return: The manifest_ids of this ResetLiveManifestTimeShift.
        :rtype: list[string_types]
        """
        return self._manifest_ids

    @manifest_ids.setter
    def manifest_ids(self, manifest_ids):
        # type: (list) -> None
        """Sets the manifest_ids of this ResetLiveManifestTimeShift.

        The ids of the manifests to update. If this property is not set, all manifests tied to the encoding are updated.

        :param manifest_ids: The manifest_ids of this ResetLiveManifestTimeShift.
        :type: list[string_types]
        """

        if manifest_ids is not None:
            if not isinstance(manifest_ids, list):
                raise TypeError("Invalid type for `manifest_ids`, type has to be `list[string_types]`")

        self._manifest_ids = manifest_ids

    @property
    def shift_progressive_muxing_start_position(self):
        # type: () -> bool
        """Gets the shift_progressive_muxing_start_position of this ResetLiveManifestTimeShift.

        If set to true, the Progressive muxing start position will be shifted to the start of the first remaining segment after the removal.  NOTE: This only works for Progressive MP4 muxings.

        :return: The shift_progressive_muxing_start_position of this ResetLiveManifestTimeShift.
        :rtype: bool
        """
        return self._shift_progressive_muxing_start_position

    @shift_progressive_muxing_start_position.setter
    def shift_progressive_muxing_start_position(self, shift_progressive_muxing_start_position):
        # type: (bool) -> None
        """Sets the shift_progressive_muxing_start_position of this ResetLiveManifestTimeShift.

        If set to true, the Progressive muxing start position will be shifted to the start of the first remaining segment after the removal.  NOTE: This only works for Progressive MP4 muxings.

        :param shift_progressive_muxing_start_position: The shift_progressive_muxing_start_position of this ResetLiveManifestTimeShift.
        :type: bool
        """

        if shift_progressive_muxing_start_position is not None:
            if not isinstance(shift_progressive_muxing_start_position, bool):
                raise TypeError("Invalid type for `shift_progressive_muxing_start_position`, type has to be `bool`")

        self._shift_progressive_muxing_start_position = shift_progressive_muxing_start_position

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ResetLiveManifestTimeShift, self), "to_dict"):
            result = super(ResetLiveManifestTimeShift, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResetLiveManifestTimeShift):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import logging
import sys

from bitmovin_api_sdk.common.bitmovin_api_logger_base import BitmovinApiLoggerBase


class BitmovinApiLogger(BitmovinApiLoggerBase):
    def __init__(self):
        # type: () -> None

        self.logger = logging.getLogger(self.__class__.__module__ + "." + self.__class__.__name__)
        self._attach_console_logging_handler_if_not_existing()

    def log(self, message, data=None):
        # type: (str, object) -> None

        if data is not None:
            self.logger.debug(message, data)
        else:
            self.logger.debug(message)

    def error(self, message, data=None):
        # type: (str, object) -> None

        if data is not None:
            self.logger.error(message, data)
        else:
            self.logger.error(message)

    def _attach_console_logging_handler_if_not_existing(self):
        # type: () -> None

        handlers = self.logger.handlers
        handler_already_exists = any(handler.name == 'bitmovin_console_handler' for handler in handlers)

        if handler_already_exists:
            return

        self.logger.setLevel(logging.DEBUG)
        console_handler = logging.StreamHandler(sys.stdout)
        console_handler.name = 'bitmovin_console_handler'
        formatter = logging.Formatter('%(asctime)-15s %(name)-5s %(levelname)-8s %(message)s')
        console_handler.setFormatter(formatter)

        self.logger.addHandler(console_handler)



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MediaType(Enum):
    VIDEO = "VIDEO"
    AUDIO = "AUDIO"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class IvSize(Enum):
    IV_8_BYTES = "8_BYTES"
    IV_16_BYTES = "16_BYTES"



from bitmovin_api_sdk.encoding.encodings.live.insertable_content.scheduled.scheduled_api import ScheduledApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.scheduled.scheduled_insertable_content_list_query_params import ScheduledInsertableContentListQueryParams



from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.assa.assa_api import AssaApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.assa.burn_in_subtitle_assa_list_query_params import BurnInSubtitleAssaListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AspectMode(Enum):
    PAD = "PAD"
    CROP = "CROP"
    STRETCH = "STRETCH"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.invitation import Invitation
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.account.organizations.groups.invitations.invitation_list_query_params import InvitationListQueryParams


class InvitationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(InvitationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, organization_id, group_id, invitation, **kwargs):
        # type: (string_types, string_types, Invitation, dict) -> Invitation
        """Add Invitation to Group

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param invitation: Invitation details
        :type invitation: Invitation, required
        :return: Invitation details
        :rtype: Invitation
        """

        return self.api_client.post(
            '/account/organizations/{organization_id}/groups/{group_id}/invitations',
            invitation,
            path_params={'organization_id': organization_id, 'group_id': group_id},
            type=Invitation,
            **kwargs
        )

    def delete(self, organization_id, group_id, invitation_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Invitation

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param invitation_id: Id of the invitation.
        :type invitation_id: string_types, required
        :return: Id of the group
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/account/organizations/{organization_id}/groups/{group_id}/invitations/{invitation_id}',
            path_params={'organization_id': organization_id, 'group_id': group_id, 'invitation_id': invitation_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, organization_id, group_id, invitation_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> Invitation
        """Invitation Details

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param invitation_id: Id of the invitation.
        :type invitation_id: string_types, required
        :return: Invitation details
        :rtype: Invitation
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}/groups/{group_id}/invitations/{invitation_id}',
            path_params={'organization_id': organization_id, 'group_id': group_id, 'invitation_id': invitation_id},
            type=Invitation,
            **kwargs
        )

    def list(self, organization_id, group_id, query_params=None, **kwargs):
        # type: (string_types, string_types, InvitationListQueryParams, dict) -> Invitation
        """List Invitations

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param query_params: Query parameters
        :type query_params: InvitationListQueryParams
        :return: List of invitations
        :rtype: Invitation
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}/groups/{group_id}/invitations',
            path_params={'organization_id': organization_id, 'group_id': group_id},
            query_params=query_params,
            pagination_response=True,
            type=Invitation,
            **kwargs
        )



# coding: utf-8


from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint


class InputStream(BitmovinResource):

    discriminator_value_class_map = {
        'INGEST': 'IngestInputStream',
        'CONCATENATION': 'ConcatenationInputStream',
        'TRIMMING_TIME_BASED': 'TimeBasedTrimmingInputStream',
        'TRIMMING_TIME_CODE_TRACK': 'TimecodeTrackTrimmingInputStream',
        'TRIMMING_H264_PICTURE_TIMING': 'H264PictureTimingTrimmingInputStream',
        'AUDIO_MIX': 'AudioMixInputStream',
        'SIDECAR_DOLBY_VISION_METADATA': 'DolbyVisionMetadataIngestInputStream',
        'CAPTION_CEA608': 'Cea608CaptionInputStream',
        'CAPTION_CEA708': 'Cea708CaptionInputStream',
        'FILE': 'FileInputStream',
        'DVB_SUBTITLE': 'DvbSubtitleInputStream',
        'DOLBY_ATMOS': 'DolbyAtmosIngestInputStream',
        'DOLBY_VISION': 'DolbyVisionInputStream'
    }

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(InputStream, self), "to_dict"):
            result = super(InputStream, self).to_dict()
        for k, v in iteritems(self.discriminator_value_class_map):
            if v == type(self).__name__:
                result['type'] = k
                break
        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.by_encoding_id_api import ByEncodingIdApi
from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.details.details_api import DetailsApi
from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.languages.languages_api import LanguagesApi
from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.ad_placements.ad_placements_api import AdPlacementsApi



from bitmovin_api_sdk.encoding.encodings.muxings.mxf.mxf_api import MxfApi
from bitmovin_api_sdk.encoding.encodings.muxings.mxf.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.mxf.mxf_muxing_list_query_params import MxfMuxingListQueryParams



from bitmovin_api_sdk.encoding.infrastructure.akamai.akamai_api import AkamaiApi
from bitmovin_api_sdk.encoding.infrastructure.akamai.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.akamai.akamai_account_list_query_params import AkamaiAccountListQueryParams



from bitmovin_api_sdk.encoding.inputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.encoding.inputs.s3_role_based.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.s3_role_based.s3_role_based_input_list_query_params import S3RoleBasedInputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.stream_keys_unassign_action import StreamKeysUnassignAction


class ActionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ActionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def unassign(self, stream_keys_unassign_action, **kwargs):
        # type: (StreamKeysUnassignAction, dict) -> StreamKeysUnassignAction
        """Unassign stream keys

        :param stream_keys_unassign_action: The action payload for unassigning stream keys
        :type stream_keys_unassign_action: StreamKeysUnassignAction, required
        :return: Stream key
        :rtype: StreamKeysUnassignAction
        """

        return self.api_client.post(
            '/encoding/live/stream-keys/actions/unassign',
            stream_keys_unassign_action,
            type=StreamKeysUnassignAction,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.scheduled_insertable_content import ScheduledInsertableContent


class ScheduleApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ScheduleApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, content_id, scheduled_insertable_content, **kwargs):
        # type: (string_types, string_types, ScheduledInsertableContent, dict) -> ScheduledInsertableContent
        """Schedule Insertable Content

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param content_id: Id of the insertable content.
        :type content_id: string_types, required
        :param scheduled_insertable_content: The scheduled insertable content to be created
        :type scheduled_insertable_content: ScheduledInsertableContent, required
        :return: Scheduled insertable content
        :rtype: ScheduledInsertableContent
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/live/insertable-content/{content_id}/schedule',
            scheduled_insertable_content,
            path_params={'encoding_id': encoding_id, 'content_id': content_id},
            type=ScheduledInsertableContent,
            **kwargs
        )

    def delete(self, encoding_id, content_id, scheduled_content_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Deschedule Insertable Content

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param content_id: Id of the insertable content.
        :type content_id: string_types, required
        :param scheduled_content_id: Id of the scheduled insertable content
        :type scheduled_content_id: string_types, required
        :return: Id of the scheduled insertable content
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/live/insertable-content/{content_id}/schedule/{scheduled_content_id}',
            path_params={'encoding_id': encoding_id, 'content_id': content_id, 'scheduled_content_id': scheduled_content_id},
            type=BitmovinResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamsEncodingProfile(Enum):
    PER_TITLE = "PER_TITLE"
    FIXED_RESOLUTIONS = "FIXED_RESOLUTIONS"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class WeightedPredictionPFrames(Enum):
    DISABLED = "DISABLED"
    SIMPLE = "SIMPLE"
    SMART = "SMART"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class InputType(Enum):
    AKAMAI_NETSTORAGE = "AKAMAI_NETSTORAGE"
    ASPERA = "ASPERA"
    AZURE = "AZURE"
    REDUNDANT_RTMP = "REDUNDANT_RTMP"
    FTP = "FTP"
    HLS = "HLS"
    GENERIC_S3 = "GENERIC_S3"
    GCS = "GCS"
    HTTP = "HTTP"
    HTTPS = "HTTPS"
    LOCAL = "LOCAL"
    RTMP = "RTMP"
    S3 = "S3"
    S3_ROLE_BASED = "S3_ROLE_BASED"
    SFTP = "SFTP"
    ZIXI = "ZIXI"
    SRT = "SRT"
    GCS_SERVICE_ACCOUNT = "GCS_SERVICE_ACCOUNT"
    DIRECT_FILE_UPLOAD = "DIRECT_FILE_UPLOAD"



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.notification_states import NotificationStates
import pprint
import six


class NotificationStateEntry(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 state=None,
                 muted=None,
                 notification_id=None,
                 resource_id=None,
                 triggered_at=None):
        # type: (string_types, NotificationStates, bool, string_types, string_types, datetime) -> None
        super(NotificationStateEntry, self).__init__(id_=id_)

        self._state = None
        self._muted = None
        self._notification_id = None
        self._resource_id = None
        self._triggered_at = None
        self.discriminator = None

        if state is not None:
            self.state = state
        if muted is not None:
            self.muted = muted
        if notification_id is not None:
            self.notification_id = notification_id
        if resource_id is not None:
            self.resource_id = resource_id
        if triggered_at is not None:
            self.triggered_at = triggered_at

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(NotificationStateEntry, self), 'openapi_types'):
            types = getattr(super(NotificationStateEntry, self), 'openapi_types')

        types.update({
            'state': 'NotificationStates',
            'muted': 'bool',
            'notification_id': 'string_types',
            'resource_id': 'string_types',
            'triggered_at': 'datetime'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(NotificationStateEntry, self), 'attribute_map'):
            attributes = getattr(super(NotificationStateEntry, self), 'attribute_map')

        attributes.update({
            'state': 'state',
            'muted': 'muted',
            'notification_id': 'notificationId',
            'resource_id': 'resourceId',
            'triggered_at': 'triggeredAt'
        })
        return attributes

    @property
    def state(self):
        # type: () -> NotificationStates
        """Gets the state of this NotificationStateEntry.


        :return: The state of this NotificationStateEntry.
        :rtype: NotificationStates
        """
        return self._state

    @state.setter
    def state(self, state):
        # type: (NotificationStates) -> None
        """Sets the state of this NotificationStateEntry.


        :param state: The state of this NotificationStateEntry.
        :type: NotificationStates
        """

        if state is not None:
            if not isinstance(state, NotificationStates):
                raise TypeError("Invalid type for `state`, type has to be `NotificationStates`")

        self._state = state

    @property
    def muted(self):
        # type: () -> bool
        """Gets the muted of this NotificationStateEntry.

        Indicate if notification was sent (required)

        :return: The muted of this NotificationStateEntry.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        # type: (bool) -> None
        """Sets the muted of this NotificationStateEntry.

        Indicate if notification was sent (required)

        :param muted: The muted of this NotificationStateEntry.
        :type: bool
        """

        if muted is not None:
            if not isinstance(muted, bool):
                raise TypeError("Invalid type for `muted`, type has to be `bool`")

        self._muted = muted

    @property
    def notification_id(self):
        # type: () -> string_types
        """Gets the notification_id of this NotificationStateEntry.

        The notification this state belongs to (required)

        :return: The notification_id of this NotificationStateEntry.
        :rtype: string_types
        """
        return self._notification_id

    @notification_id.setter
    def notification_id(self, notification_id):
        # type: (string_types) -> None
        """Sets the notification_id of this NotificationStateEntry.

        The notification this state belongs to (required)

        :param notification_id: The notification_id of this NotificationStateEntry.
        :type: string_types
        """

        if notification_id is not None:
            if not isinstance(notification_id, string_types):
                raise TypeError("Invalid type for `notification_id`, type has to be `string_types`")

        self._notification_id = notification_id

    @property
    def resource_id(self):
        # type: () -> string_types
        """Gets the resource_id of this NotificationStateEntry.

        Indicate if triggered for specific resource (required)

        :return: The resource_id of this NotificationStateEntry.
        :rtype: string_types
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        # type: (string_types) -> None
        """Sets the resource_id of this NotificationStateEntry.

        Indicate if triggered for specific resource (required)

        :param resource_id: The resource_id of this NotificationStateEntry.
        :type: string_types
        """

        if resource_id is not None:
            if not isinstance(resource_id, string_types):
                raise TypeError("Invalid type for `resource_id`, type has to be `string_types`")

        self._resource_id = resource_id

    @property
    def triggered_at(self):
        # type: () -> datetime
        """Gets the triggered_at of this NotificationStateEntry.


        :return: The triggered_at of this NotificationStateEntry.
        :rtype: datetime
        """
        return self._triggered_at

    @triggered_at.setter
    def triggered_at(self, triggered_at):
        # type: (datetime) -> None
        """Sets the triggered_at of this NotificationStateEntry.


        :param triggered_at: The triggered_at of this NotificationStateEntry.
        :type: datetime
        """

        if triggered_at is not None:
            if not isinstance(triggered_at, datetime):
                raise TypeError("Invalid type for `triggered_at`, type has to be `datetime`")

        self._triggered_at = triggered_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(NotificationStateEntry, self), "to_dict"):
            result = super(NotificationStateEntry, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationStateEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.content import Content
from bitmovin_api_sdk.models.iab_taxonomy import IABTaxonomy
from bitmovin_api_sdk.models.scene_type import SceneType
import pprint
import six


class Scene(object):
    @poscheck_model
    def __init__(self,
                 title=None,
                 start_in_seconds=None,
                 end_in_seconds=None,
                 id_=None,
                 content=None,
                 summary=None,
                 verbose_summary=None,
                 sensitive_topics=None,
                 keywords=None,
                 iab=None,
                 type_=None,
                 type_confidence=None):
        # type: (string_types, float, float, string_types, Content, string_types, string_types, list[string_types], list[string_types], IABTaxonomy, SceneType, float) -> None

        self._title = None
        self._start_in_seconds = None
        self._end_in_seconds = None
        self._id = None
        self._content = None
        self._summary = None
        self._verbose_summary = None
        self._sensitive_topics = list()
        self._keywords = list()
        self._iab = None
        self._type = None
        self._type_confidence = None
        self.discriminator = None

        if title is not None:
            self.title = title
        if start_in_seconds is not None:
            self.start_in_seconds = start_in_seconds
        if end_in_seconds is not None:
            self.end_in_seconds = end_in_seconds
        if id_ is not None:
            self.id = id_
        if content is not None:
            self.content = content
        if summary is not None:
            self.summary = summary
        if verbose_summary is not None:
            self.verbose_summary = verbose_summary
        if sensitive_topics is not None:
            self.sensitive_topics = sensitive_topics
        if keywords is not None:
            self.keywords = keywords
        if iab is not None:
            self.iab = iab
        if type_ is not None:
            self.type = type_
        if type_confidence is not None:
            self.type_confidence = type_confidence

    @property
    def openapi_types(self):
        types = {
            'title': 'string_types',
            'start_in_seconds': 'float',
            'end_in_seconds': 'float',
            'id': 'string_types',
            'content': 'Content',
            'summary': 'string_types',
            'verbose_summary': 'string_types',
            'sensitive_topics': 'list[string_types]',
            'keywords': 'list[string_types]',
            'iab': 'IABTaxonomy',
            'type': 'SceneType',
            'type_confidence': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'title': 'title',
            'start_in_seconds': 'startInSeconds',
            'end_in_seconds': 'endInSeconds',
            'id': 'id',
            'content': 'content',
            'summary': 'summary',
            'verbose_summary': 'verboseSummary',
            'sensitive_topics': 'sensitiveTopics',
            'keywords': 'keywords',
            'iab': 'iab',
            'type': 'type',
            'type_confidence': 'typeConfidence'
        }
        return attributes

    @property
    def title(self):
        # type: () -> string_types
        """Gets the title of this Scene.


        :return: The title of this Scene.
        :rtype: string_types
        """
        return self._title

    @title.setter
    def title(self, title):
        # type: (string_types) -> None
        """Sets the title of this Scene.


        :param title: The title of this Scene.
        :type: string_types
        """

        if title is not None:
            if not isinstance(title, string_types):
                raise TypeError("Invalid type for `title`, type has to be `string_types`")

        self._title = title

    @property
    def start_in_seconds(self):
        # type: () -> float
        """Gets the start_in_seconds of this Scene.


        :return: The start_in_seconds of this Scene.
        :rtype: float
        """
        return self._start_in_seconds

    @start_in_seconds.setter
    def start_in_seconds(self, start_in_seconds):
        # type: (float) -> None
        """Sets the start_in_seconds of this Scene.


        :param start_in_seconds: The start_in_seconds of this Scene.
        :type: float
        """

        if start_in_seconds is not None:
            if not isinstance(start_in_seconds, (float, int)):
                raise TypeError("Invalid type for `start_in_seconds`, type has to be `float`")

        self._start_in_seconds = start_in_seconds

    @property
    def end_in_seconds(self):
        # type: () -> float
        """Gets the end_in_seconds of this Scene.


        :return: The end_in_seconds of this Scene.
        :rtype: float
        """
        return self._end_in_seconds

    @end_in_seconds.setter
    def end_in_seconds(self, end_in_seconds):
        # type: (float) -> None
        """Sets the end_in_seconds of this Scene.


        :param end_in_seconds: The end_in_seconds of this Scene.
        :type: float
        """

        if end_in_seconds is not None:
            if not isinstance(end_in_seconds, (float, int)):
                raise TypeError("Invalid type for `end_in_seconds`, type has to be `float`")

        self._end_in_seconds = end_in_seconds

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this Scene.


        :return: The id of this Scene.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this Scene.


        :param id_: The id of this Scene.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def content(self):
        # type: () -> Content
        """Gets the content of this Scene.


        :return: The content of this Scene.
        :rtype: Content
        """
        return self._content

    @content.setter
    def content(self, content):
        # type: (Content) -> None
        """Sets the content of this Scene.


        :param content: The content of this Scene.
        :type: Content
        """

        if content is not None:
            if not isinstance(content, Content):
                raise TypeError("Invalid type for `content`, type has to be `Content`")

        self._content = content

    @property
    def summary(self):
        # type: () -> string_types
        """Gets the summary of this Scene.


        :return: The summary of this Scene.
        :rtype: string_types
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        # type: (string_types) -> None
        """Sets the summary of this Scene.


        :param summary: The summary of this Scene.
        :type: string_types
        """

        if summary is not None:
            if not isinstance(summary, string_types):
                raise TypeError("Invalid type for `summary`, type has to be `string_types`")

        self._summary = summary

    @property
    def verbose_summary(self):
        # type: () -> string_types
        """Gets the verbose_summary of this Scene.


        :return: The verbose_summary of this Scene.
        :rtype: string_types
        """
        return self._verbose_summary

    @verbose_summary.setter
    def verbose_summary(self, verbose_summary):
        # type: (string_types) -> None
        """Sets the verbose_summary of this Scene.


        :param verbose_summary: The verbose_summary of this Scene.
        :type: string_types
        """

        if verbose_summary is not None:
            if not isinstance(verbose_summary, string_types):
                raise TypeError("Invalid type for `verbose_summary`, type has to be `string_types`")

        self._verbose_summary = verbose_summary

    @property
    def sensitive_topics(self):
        # type: () -> list[string_types]
        """Gets the sensitive_topics of this Scene.


        :return: The sensitive_topics of this Scene.
        :rtype: list[string_types]
        """
        return self._sensitive_topics

    @sensitive_topics.setter
    def sensitive_topics(self, sensitive_topics):
        # type: (list) -> None
        """Sets the sensitive_topics of this Scene.


        :param sensitive_topics: The sensitive_topics of this Scene.
        :type: list[string_types]
        """

        if sensitive_topics is not None:
            if not isinstance(sensitive_topics, list):
                raise TypeError("Invalid type for `sensitive_topics`, type has to be `list[string_types]`")

        self._sensitive_topics = sensitive_topics

    @property
    def keywords(self):
        # type: () -> list[string_types]
        """Gets the keywords of this Scene.


        :return: The keywords of this Scene.
        :rtype: list[string_types]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        # type: (list) -> None
        """Sets the keywords of this Scene.


        :param keywords: The keywords of this Scene.
        :type: list[string_types]
        """

        if keywords is not None:
            if not isinstance(keywords, list):
                raise TypeError("Invalid type for `keywords`, type has to be `list[string_types]`")

        self._keywords = keywords

    @property
    def iab(self):
        # type: () -> IABTaxonomy
        """Gets the iab of this Scene.


        :return: The iab of this Scene.
        :rtype: IABTaxonomy
        """
        return self._iab

    @iab.setter
    def iab(self, iab):
        # type: (IABTaxonomy) -> None
        """Sets the iab of this Scene.


        :param iab: The iab of this Scene.
        :type: IABTaxonomy
        """

        if iab is not None:
            if not isinstance(iab, IABTaxonomy):
                raise TypeError("Invalid type for `iab`, type has to be `IABTaxonomy`")

        self._iab = iab

    @property
    def type(self):
        # type: () -> SceneType
        """Gets the type of this Scene.

        The detected type of scene based on content analysis

        :return: The type of this Scene.
        :rtype: SceneType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (SceneType) -> None
        """Sets the type of this Scene.

        The detected type of scene based on content analysis

        :param type_: The type of this Scene.
        :type: SceneType
        """

        if type_ is not None:
            if not isinstance(type_, SceneType):
                raise TypeError("Invalid type for `type`, type has to be `SceneType`")

        self._type = type_

    @property
    def type_confidence(self):
        # type: () -> float
        """Gets the type_confidence of this Scene.

        Confidence score for the detected scene type (0.0 to 1.0)

        :return: The type_confidence of this Scene.
        :rtype: float
        """
        return self._type_confidence

    @type_confidence.setter
    def type_confidence(self, type_confidence):
        # type: (float) -> None
        """Sets the type_confidence of this Scene.

        Confidence score for the detected scene type (0.0 to 1.0)

        :param type_confidence: The type_confidence of this Scene.
        :type: float
        """

        if type_confidence is not None:
            if type_confidence is not None and type_confidence > 1:
                raise ValueError("Invalid value for `type_confidence`, must be a value less than or equal to `1`")
            if type_confidence is not None and type_confidence < 0:
                raise ValueError("Invalid value for `type_confidence`, must be a value greater than or equal to `0`")
            if not isinstance(type_confidence, (float, int)):
                raise TypeError("Invalid type for `type_confidence`, type has to be `float`")

        self._type_confidence = type_confidence

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Scene):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.aspect_mode import AspectMode
from bitmovin_api_sdk.models.padding_sequence import PaddingSequence
import pprint
import six


class ConcatenationInputConfiguration(object):
    @poscheck_model
    def __init__(self,
                 input_stream_id=None,
                 is_main=None,
                 position=None,
                 padding_before=None,
                 padding_after=None,
                 aspect_mode=None):
        # type: (string_types, bool, int, PaddingSequence, PaddingSequence, AspectMode) -> None

        self._input_stream_id = None
        self._is_main = None
        self._position = None
        self._padding_before = None
        self._padding_after = None
        self._aspect_mode = None
        self.discriminator = None

        if input_stream_id is not None:
            self.input_stream_id = input_stream_id
        if is_main is not None:
            self.is_main = is_main
        if position is not None:
            self.position = position
        if padding_before is not None:
            self.padding_before = padding_before
        if padding_after is not None:
            self.padding_after = padding_after
        if aspect_mode is not None:
            self.aspect_mode = aspect_mode

    @property
    def openapi_types(self):
        types = {
            'input_stream_id': 'string_types',
            'is_main': 'bool',
            'position': 'int',
            'padding_before': 'PaddingSequence',
            'padding_after': 'PaddingSequence',
            'aspect_mode': 'AspectMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'input_stream_id': 'inputStreamId',
            'is_main': 'isMain',
            'position': 'position',
            'padding_before': 'paddingBefore',
            'padding_after': 'paddingAfter',
            'aspect_mode': 'aspectMode'
        }
        return attributes

    @property
    def input_stream_id(self):
        # type: () -> string_types
        """Gets the input_stream_id of this ConcatenationInputConfiguration.

        The ID of the input stream to be concatenated. This can be an ingest input stream or a trimming input stream (required)

        :return: The input_stream_id of this ConcatenationInputConfiguration.
        :rtype: string_types
        """
        return self._input_stream_id

    @input_stream_id.setter
    def input_stream_id(self, input_stream_id):
        # type: (string_types) -> None
        """Sets the input_stream_id of this ConcatenationInputConfiguration.

        The ID of the input stream to be concatenated. This can be an ingest input stream or a trimming input stream (required)

        :param input_stream_id: The input_stream_id of this ConcatenationInputConfiguration.
        :type: string_types
        """

        if input_stream_id is not None:
            if not isinstance(input_stream_id, string_types):
                raise TypeError("Invalid type for `input_stream_id`, type has to be `string_types`")

        self._input_stream_id = input_stream_id

    @property
    def is_main(self):
        # type: () -> bool
        """Gets the is_main of this ConcatenationInputConfiguration.

        Exactly one input stream of a concatenation must have this set to true, which will be used as reference for scaling, aspect ratio, FPS, sample rate, etc. 

        :return: The is_main of this ConcatenationInputConfiguration.
        :rtype: bool
        """
        return self._is_main

    @is_main.setter
    def is_main(self, is_main):
        # type: (bool) -> None
        """Sets the is_main of this ConcatenationInputConfiguration.

        Exactly one input stream of a concatenation must have this set to true, which will be used as reference for scaling, aspect ratio, FPS, sample rate, etc. 

        :param is_main: The is_main of this ConcatenationInputConfiguration.
        :type: bool
        """

        if is_main is not None:
            if not isinstance(is_main, bool):
                raise TypeError("Invalid type for `is_main`, type has to be `bool`")

        self._is_main = is_main

    @property
    def position(self):
        # type: () -> int
        """Gets the position of this ConcatenationInputConfiguration.

        A unique integer value that determines concatenation order (required)

        :return: The position of this ConcatenationInputConfiguration.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        # type: (int) -> None
        """Sets the position of this ConcatenationInputConfiguration.

        A unique integer value that determines concatenation order (required)

        :param position: The position of this ConcatenationInputConfiguration.
        :type: int
        """

        if position is not None:
            if position is not None and position < 0:
                raise ValueError("Invalid value for `position`, must be a value greater than or equal to `0`")
            if not isinstance(position, int):
                raise TypeError("Invalid type for `position`, type has to be `int`")

        self._position = position

    @property
    def padding_before(self):
        # type: () -> PaddingSequence
        """Gets the padding_before of this ConcatenationInputConfiguration.

        Inserts a padding sequence (black frames and/or silent audio) before the input stream.

        :return: The padding_before of this ConcatenationInputConfiguration.
        :rtype: PaddingSequence
        """
        return self._padding_before

    @padding_before.setter
    def padding_before(self, padding_before):
        # type: (PaddingSequence) -> None
        """Sets the padding_before of this ConcatenationInputConfiguration.

        Inserts a padding sequence (black frames and/or silent audio) before the input stream.

        :param padding_before: The padding_before of this ConcatenationInputConfiguration.
        :type: PaddingSequence
        """

        if padding_before is not None:
            if not isinstance(padding_before, PaddingSequence):
                raise TypeError("Invalid type for `padding_before`, type has to be `PaddingSequence`")

        self._padding_before = padding_before

    @property
    def padding_after(self):
        # type: () -> PaddingSequence
        """Gets the padding_after of this ConcatenationInputConfiguration.

        Inserts a padding sequence (black frames and/or silent audio) after the input stream.

        :return: The padding_after of this ConcatenationInputConfiguration.
        :rtype: PaddingSequence
        """
        return self._padding_after

    @padding_after.setter
    def padding_after(self, padding_after):
        # type: (PaddingSequence) -> None
        """Sets the padding_after of this ConcatenationInputConfiguration.

        Inserts a padding sequence (black frames and/or silent audio) after the input stream.

        :param padding_after: The padding_after of this ConcatenationInputConfiguration.
        :type: PaddingSequence
        """

        if padding_after is not None:
            if not isinstance(padding_after, PaddingSequence):
                raise TypeError("Invalid type for `padding_after`, type has to be `PaddingSequence`")

        self._padding_after = padding_after

    @property
    def aspect_mode(self):
        # type: () -> AspectMode
        """Gets the aspect_mode of this ConcatenationInputConfiguration.

        Specifies the aspect mode that is used when adapting to the main input stream's aspect ratio

        :return: The aspect_mode of this ConcatenationInputConfiguration.
        :rtype: AspectMode
        """
        return self._aspect_mode

    @aspect_mode.setter
    def aspect_mode(self, aspect_mode):
        # type: (AspectMode) -> None
        """Sets the aspect_mode of this ConcatenationInputConfiguration.

        Specifies the aspect mode that is used when adapting to the main input stream's aspect ratio

        :param aspect_mode: The aspect_mode of this ConcatenationInputConfiguration.
        :type: AspectMode
        """

        if aspect_mode is not None:
            if not isinstance(aspect_mode, AspectMode):
                raise TypeError("Invalid type for `aspect_mode`, type has to be `AspectMode`")

        self._aspect_mode = aspect_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConcatenationInputConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.smooth_streaming_manifest import SmoothStreamingManifest
from bitmovin_api_sdk.models.start_manifest_request import StartManifestRequest
from bitmovin_api_sdk.models.task import Task
from bitmovin_api_sdk.encoding.manifests.smooth.default.default_api import DefaultApi
from bitmovin_api_sdk.encoding.manifests.smooth.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.manifests.smooth.representations.representations_api import RepresentationsApi
from bitmovin_api_sdk.encoding.manifests.smooth.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.smooth.smooth_streaming_manifest_list_query_params import SmoothStreamingManifestListQueryParams


class SmoothApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SmoothApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.default = DefaultApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.representations = RepresentationsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.contentprotection = ContentprotectionApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, smooth_streaming_manifest, **kwargs):
        # type: (SmoothStreamingManifest, dict) -> SmoothStreamingManifest
        """Create Smooth Streaming Manifest

        :param smooth_streaming_manifest: The Custom Smooth Streaming Manifest to be created.
        :type smooth_streaming_manifest: SmoothStreamingManifest, required
        :return: Smooth Streaming manifest
        :rtype: SmoothStreamingManifest
        """

        return self.api_client.post(
            '/encoding/manifests/smooth',
            smooth_streaming_manifest,
            type=SmoothStreamingManifest,
            **kwargs
        )

    def delete(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Smooth Streaming Manifest

        :param manifest_id: Id of the Smooth Streaming Manifest.
        :type manifest_id: string_types, required
        :return: Id of the manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/smooth/{manifest_id}',
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> SmoothStreamingManifest
        """Smooth Streaming Manifest Details

        :param manifest_id: Id of the Smooth Streaming Manifest.
        :type manifest_id: string_types, required
        :return: Manifest details
        :rtype: SmoothStreamingManifest
        """

        return self.api_client.get(
            '/encoding/manifests/smooth/{manifest_id}',
            path_params={'manifest_id': manifest_id},
            type=SmoothStreamingManifest,
            **kwargs
        )

    def get_start_request(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> StartManifestRequest
        """Manifest Start Details

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :return: Service specific result
        :rtype: StartManifestRequest
        """

        return self.api_client.get(
            '/encoding/manifests/smooth/{manifest_id}/start',
            path_params={'manifest_id': manifest_id},
            type=StartManifestRequest,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (SmoothStreamingManifestListQueryParams, dict) -> SmoothStreamingManifest
        """List Smooth Streaming Manifests

        :param query_params: Query parameters
        :type query_params: SmoothStreamingManifestListQueryParams
        :return: Manifest results
        :rtype: SmoothStreamingManifest
        """

        return self.api_client.get(
            '/encoding/manifests/smooth',
            query_params=query_params,
            pagination_response=True,
            type=SmoothStreamingManifest,
            **kwargs
        )

    def start(self, manifest_id, start_manifest_request=None, **kwargs):
        # type: (string_types, StartManifestRequest, dict) -> BitmovinResponse
        """Start Smooth Streaming manifest generation

        :param manifest_id: Id of the Smooth Streaming Manifest.
        :type manifest_id: string_types, required
        :param start_manifest_request: Manifest Startup Options
        :type start_manifest_request: StartManifestRequest
        :return: Id of the manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/manifests/smooth/{manifest_id}/start',
            start_manifest_request,
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )

    def status(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> Task
        """Smooth Streaming manifest generation status

        :param manifest_id: Id of the Smooth Streaming Manifest.
        :type manifest_id: string_types, required
        :return: Status of manifest generation
        :rtype: Task
        """

        return self.api_client.get(
            '/encoding/manifests/smooth/{manifest_id}/status',
            path_params={'manifest_id': manifest_id},
            type=Task,
            **kwargs
        )

    def stop(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Stop Smooth Streaming manifest generation

        :param manifest_id: Id of the Smooth Streaming Manifest.
        :type manifest_id: string_types, required
        :return: Id of the Smooth Streaming Manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/manifests/smooth/{manifest_id}/stop',
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class TsProgramClockReferenceConfiguration(object):
    @poscheck_model
    def __init__(self,
                 pid=None,
                 interval=None):
        # type: (int, int) -> None

        self._pid = None
        self._interval = None
        self.discriminator = None

        if pid is not None:
            self.pid = pid
        if interval is not None:
            self.interval = interval

    @property
    def openapi_types(self):
        types = {
            'pid': 'int',
            'interval': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'pid': 'pid',
            'interval': 'interval'
        }
        return attributes

    @property
    def pid(self):
        # type: () -> int
        """Gets the pid of this TsProgramClockReferenceConfiguration.

        An integer value. Packet Identifier (PID) for the MPEG Transport Stream PCR. This should generally point to the video stream PID. If it is not explicitly set it will point to the video stream PID if exists, otherwise to the audio stream PID.

        :return: The pid of this TsProgramClockReferenceConfiguration.
        :rtype: int
        """
        return self._pid

    @pid.setter
    def pid(self, pid):
        # type: (int) -> None
        """Sets the pid of this TsProgramClockReferenceConfiguration.

        An integer value. Packet Identifier (PID) for the MPEG Transport Stream PCR. This should generally point to the video stream PID. If it is not explicitly set it will point to the video stream PID if exists, otherwise to the audio stream PID.

        :param pid: The pid of this TsProgramClockReferenceConfiguration.
        :type: int
        """

        if pid is not None:
            if pid is not None and pid > 8190:
                raise ValueError("Invalid value for `pid`, must be a value less than or equal to `8190`")
            if pid is not None and pid < 16:
                raise ValueError("Invalid value for `pid`, must be a value greater than or equal to `16`")
            if not isinstance(pid, int):
                raise TypeError("Invalid type for `pid`, type has to be `int`")

        self._pid = pid

    @property
    def interval(self):
        # type: () -> int
        """Gets the interval of this TsProgramClockReferenceConfiguration.

        An integer value. Nominal time between MPEG Transport Stream PCRs in milliseconds.

        :return: The interval of this TsProgramClockReferenceConfiguration.
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        # type: (int) -> None
        """Sets the interval of this TsProgramClockReferenceConfiguration.

        An integer value. Nominal time between MPEG Transport Stream PCRs in milliseconds.

        :param interval: The interval of this TsProgramClockReferenceConfiguration.
        :type: int
        """

        if interval is not None:
            if interval is not None and interval > 65535:
                raise ValueError("Invalid value for `interval`, must be a value less than or equal to `65535`")
            if interval is not None and interval < 1:
                raise ValueError("Invalid value for `interval`, must be a value greater than or equal to `1`")
            if not isinstance(interval, int):
                raise TypeError("Invalid type for `interval`, type has to be `int`")

        self._interval = interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsProgramClockReferenceConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ConditionAttribute(Enum):
    HEIGHT = "HEIGHT"
    WIDTH = "WIDTH"
    BITRATE = "BITRATE"
    FPS = "FPS"
    ASPECTRATIO = "ASPECTRATIO"
    INPUTSTREAM = "INPUTSTREAM"
    LANGUAGE = "LANGUAGE"
    CHANNELFORMAT = "CHANNELFORMAT"
    CHANNELLAYOUT = "CHANNELLAYOUT"
    STREAMCOUNT = "STREAMCOUNT"
    AUDIOSTREAMCOUNT = "AUDIOSTREAMCOUNT"
    VIDEOSTREAMCOUNT = "VIDEOSTREAMCOUNT"
    DURATION = "DURATION"
    ROTATION = "ROTATION"
    CONNECTION_STATUS = "CONNECTION_STATUS"
    CONNECTION_STATUS_JUST_CHANGED = "CONNECTION_STATUS_JUST_CHANGED"



from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.srt.srt_api import SrtApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.srt.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.srt.srt_to_cea608708_caption_list_query_params import SrtToCea608708CaptionListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.watch_folder_input import WatchFolderInput
from bitmovin_api_sdk.models.watch_folder_status import WatchFolderStatus
import pprint
import six


class WatchFolder(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_=None,
                 outputs=None,
                 status=None,
                 status_text=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, WatchFolderInput, list[WatchFolderOutput], WatchFolderStatus, string_types) -> None
        super(WatchFolder, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._input = None
        self._outputs = list()
        self._status = None
        self._status_text = None
        self.discriminator = None

        if input_ is not None:
            self.input = input_
        if outputs is not None:
            self.outputs = outputs
        if status is not None:
            self.status = status
        if status_text is not None:
            self.status_text = status_text

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(WatchFolder, self), 'openapi_types'):
            types = getattr(super(WatchFolder, self), 'openapi_types')

        types.update({
            'input': 'WatchFolderInput',
            'outputs': 'list[WatchFolderOutput]',
            'status': 'WatchFolderStatus',
            'status_text': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(WatchFolder, self), 'attribute_map'):
            attributes = getattr(super(WatchFolder, self), 'attribute_map')

        attributes.update({
            'input': 'input',
            'outputs': 'outputs',
            'status': 'status',
            'status_text': 'statusText'
        })
        return attributes

    @property
    def input(self):
        # type: () -> WatchFolderInput
        """Gets the input of this WatchFolder.


        :return: The input of this WatchFolder.
        :rtype: WatchFolderInput
        """
        return self._input

    @input.setter
    def input(self, input_):
        # type: (WatchFolderInput) -> None
        """Sets the input of this WatchFolder.


        :param input_: The input of this WatchFolder.
        :type: WatchFolderInput
        """

        if input_ is not None:
            if not isinstance(input_, WatchFolderInput):
                raise TypeError("Invalid type for `input`, type has to be `WatchFolderInput`")

        self._input = input_

    @property
    def outputs(self):
        # type: () -> list[WatchFolderOutput]
        """Gets the outputs of this WatchFolder.


        :return: The outputs of this WatchFolder.
        :rtype: list[WatchFolderOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this WatchFolder.


        :param outputs: The outputs of this WatchFolder.
        :type: list[WatchFolderOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[WatchFolderOutput]`")

        self._outputs = outputs

    @property
    def status(self):
        # type: () -> WatchFolderStatus
        """Gets the status of this WatchFolder.

        The current status of the Watch Folder. The default value is `STOPPED` (required)

        :return: The status of this WatchFolder.
        :rtype: WatchFolderStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (WatchFolderStatus) -> None
        """Sets the status of this WatchFolder.

        The current status of the Watch Folder. The default value is `STOPPED` (required)

        :param status: The status of this WatchFolder.
        :type: WatchFolderStatus
        """

        if status is not None:
            if not isinstance(status, WatchFolderStatus):
                raise TypeError("Invalid type for `status`, type has to be `WatchFolderStatus`")

        self._status = status

    @property
    def status_text(self):
        # type: () -> string_types
        """Gets the status_text of this WatchFolder.

        A description text of the current status (required)

        :return: The status_text of this WatchFolder.
        :rtype: string_types
        """
        return self._status_text

    @status_text.setter
    def status_text(self, status_text):
        # type: (string_types) -> None
        """Sets the status_text of this WatchFolder.

        A description text of the current status (required)

        :param status_text: The status_text of this WatchFolder.
        :type: string_types
        """

        if status_text is not None:
            if not isinstance(status_text, string_types):
                raise TypeError("Invalid type for `status_text`, type has to be `string_types`")

        self._status_text = status_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(WatchFolder, self), "to_dict"):
            result = super(WatchFolder, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WatchFolder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PerTitleFixedResolutionAndBitrateConfigurationMode(Enum):
    LAST_CALCULATED_BITRATE = "LAST_CALCULATED_BITRATE"
    MINIMUM = "MINIMUM"
    MAXIMUM = "MAXIMUM"
    AVERAGE = "AVERAGE"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.encoding.configurations.video.h262.h262_api import H262Api
from bitmovin_api_sdk.encoding.configurations.video.h264.h264_api import H264Api
from bitmovin_api_sdk.encoding.configurations.video.h265.h265_api import H265Api
from bitmovin_api_sdk.encoding.configurations.video.vp8.vp8_api import Vp8Api
from bitmovin_api_sdk.encoding.configurations.video.vp9.vp9_api import Vp9Api
from bitmovin_api_sdk.encoding.configurations.video.av1.av1_api import Av1Api
from bitmovin_api_sdk.encoding.configurations.video.mjpeg.mjpeg_api import MjpegApi


class VideoApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(VideoApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.h262 = H262Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.h264 = H264Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.h265 = H265Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.vp8 = Vp8Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.vp9 = Vp9Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.av1 = Av1Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mjpeg = MjpegApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.scte35_trigger import Scte35Trigger
from bitmovin_api_sdk.encoding.encodings.scte35_triggers.scte35_trigger_list_query_params import Scte35TriggerListQueryParams


class Scte35TriggersApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(Scte35TriggersApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, scte35_trigger, **kwargs):
        # type: (string_types, Scte35Trigger, dict) -> Scte35Trigger
        """Create SCTE 35 trigger

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param scte35_trigger: The SCTE 35 trigger to be created
        :type scte35_trigger: Scte35Trigger, required
        :return: SCTE 35 trigger
        :rtype: Scte35Trigger
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/scte-35-triggers',
            scte35_trigger,
            path_params={'encoding_id': encoding_id},
            type=Scte35Trigger,
            **kwargs
        )

    def delete(self, encoding_id, scte35trigger_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete SCTE 35 trigger

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param scte35trigger_id: Id of the SCTE 35 trigger
        :type scte35trigger_id: string_types, required
        :return: Id of the SCTE 35 trigger
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/scte-35-triggers/{scte35trigger_id}',
            path_params={'encoding_id': encoding_id, 'scte35trigger_id': scte35trigger_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, scte35trigger_id, **kwargs):
        # type: (string_types, string_types, dict) -> Scte35Trigger
        """SCTE 35 trigger Details

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param scte35trigger_id: Id of the SCTE 35 trigger
        :type scte35trigger_id: string_types, required
        :return: SCTE 35 trigger
        :rtype: Scte35Trigger
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/scte-35-triggers/{scte35trigger_id}',
            path_params={'encoding_id': encoding_id, 'scte35trigger_id': scte35trigger_id},
            type=Scte35Trigger,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, Scte35TriggerListQueryParams, dict) -> Scte35Trigger
        """List all SCTE 35 triggers for an encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: Scte35TriggerListQueryParams
        :return: List of SCTE 35 triggers
        :rtype: Scte35Trigger
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/scte-35-triggers',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=Scte35Trigger,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Vp9Quality(Enum):
    REALTIME = "REALTIME"
    GOOD = "GOOD"
    BEST = "BEST"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.audio_adaptation_set import AudioAdaptationSet
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.audio.audio_adaptation_set_list_query_params import AudioAdaptationSetListQueryParams


class AudioApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AudioApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, period_id, audio_adaptation_set, **kwargs):
        # type: (string_types, string_types, AudioAdaptationSet, dict) -> AudioAdaptationSet
        """Add Audio AdaptationSet

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param audio_adaptation_set: The audio adaptation set to be added to the period
        :type audio_adaptation_set: AudioAdaptationSet, required
        :return: AudioAdaptationSet
        :rtype: AudioAdaptationSet
        """

        return self.api_client.post(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/audio',
            audio_adaptation_set,
            path_params={'manifest_id': manifest_id, 'period_id': period_id},
            type=AudioAdaptationSet,
            **kwargs
        )

    def delete(self, manifest_id, period_id, adaptationset_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Audio AdaptationSet

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the audio adaptation set to be deleted
        :type adaptationset_id: string_types, required
        :return: Id of the Audio AdaptationSet
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/audio/{adaptationset_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, period_id, adaptationset_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> AudioAdaptationSet
        """Audio AdaptationSet Details

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the audio adaptation set
        :type adaptationset_id: string_types, required
        :return: Audio AdaptationSet details
        :rtype: AudioAdaptationSet
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/audio/{adaptationset_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id},
            type=AudioAdaptationSet,
            **kwargs
        )

    def list(self, manifest_id, period_id, query_params=None, **kwargs):
        # type: (string_types, string_types, AudioAdaptationSetListQueryParams, dict) -> AudioAdaptationSet
        """List all Audio AdaptationSets

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param query_params: Query parameters
        :type query_params: AudioAdaptationSetListQueryParams
        :return: List of Audio AdaptationSets
        :rtype: AudioAdaptationSet
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/audio',
            path_params={'manifest_id': manifest_id, 'period_id': period_id},
            query_params=query_params,
            pagination_response=True,
            type=AudioAdaptationSet,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.clearkey.clearkey_api import ClearkeyApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.clearkey.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.clearkey.clear_key_drm_list_query_params import ClearKeyDrmListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.azure_speech_to_captions_filter import AzureSpeechToCaptionsFilter
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.filters.azure_speech_to_captions.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.azure_speech_to_captions.azure_speech_to_captions_filter_list_query_params import AzureSpeechToCaptionsFilterListQueryParams


class AzureSpeechToCaptionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AzureSpeechToCaptionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, azure_speech_to_captions_filter, **kwargs):
        # type: (AzureSpeechToCaptionsFilter, dict) -> AzureSpeechToCaptionsFilter
        """Create Azure Speech to captions Filter

        :param azure_speech_to_captions_filter: The Azure Speech to captions Filter to be created
        :type azure_speech_to_captions_filter: AzureSpeechToCaptionsFilter, required
        :return: Azure Speech to captions details
        :rtype: AzureSpeechToCaptionsFilter
        """

        return self.api_client.post(
            '/encoding/filters/azure-speech-to-captions',
            azure_speech_to_captions_filter,
            type=AzureSpeechToCaptionsFilter,
            **kwargs
        )

    def delete(self, filter_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Azure Speech to captions Filter

        :param filter_id: Id of the Azure Speech to captions Filter.
        :type filter_id: string_types, required
        :return: Id of the Azure Speech to captions filter.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/filters/azure-speech-to-captions/{filter_id}',
            path_params={'filter_id': filter_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, filter_id, **kwargs):
        # type: (string_types, dict) -> AzureSpeechToCaptionsFilter
        """Azure Speech to captions Filter details

        :param filter_id: Id of the Azure Speech to captions Filter.
        :type filter_id: string_types, required
        :return: Azure Speech to captions filter details
        :rtype: AzureSpeechToCaptionsFilter
        """

        return self.api_client.get(
            '/encoding/filters/azure-speech-to-captions/{filter_id}',
            path_params={'filter_id': filter_id},
            type=AzureSpeechToCaptionsFilter,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AzureSpeechToCaptionsFilterListQueryParams, dict) -> AzureSpeechToCaptionsFilter
        """List Azure Speech to captions Filters

        :param query_params: Query parameters
        :type query_params: AzureSpeechToCaptionsFilterListQueryParams
        :return: List of Azure Speech to captions Filters
        :rtype: AzureSpeechToCaptionsFilter
        """

        return self.api_client.get(
            '/encoding/filters/azure-speech-to-captions',
            query_params=query_params,
            pagination_response=True,
            type=AzureSpeechToCaptionsFilter,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class NotificationStates(Enum):
    FIRED = "FIRED"
    RESOLVED = "RESOLVED"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.signature_type import SignatureType
import pprint
import six


class WebhookSignature(object):
    @poscheck_model
    def __init__(self,
                 type_=None,
                 key=None):
        # type: (SignatureType, string_types) -> None

        self._type = None
        self._key = None
        self.discriminator = None

        if type_ is not None:
            self.type = type_
        if key is not None:
            self.key = key

    @property
    def openapi_types(self):
        types = {
            'type': 'SignatureType',
            'key': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'type': 'type',
            'key': 'key'
        }
        return attributes

    @property
    def type(self):
        # type: () -> SignatureType
        """Gets the type of this WebhookSignature.

        The signature type used for the webhook.  Selects one of the supported signatures. The signature is attached to the list of headers with the key `Bitmovin-Signature`. In case of the `HMAC` type the SHA512 hashing algorithm is used to generate an authentication code from the webhook body. (required)

        :return: The type of this WebhookSignature.
        :rtype: SignatureType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (SignatureType) -> None
        """Sets the type of this WebhookSignature.

        The signature type used for the webhook.  Selects one of the supported signatures. The signature is attached to the list of headers with the key `Bitmovin-Signature`. In case of the `HMAC` type the SHA512 hashing algorithm is used to generate an authentication code from the webhook body. (required)

        :param type_: The type of this WebhookSignature.
        :type: SignatureType
        """

        if type_ is not None:
            if not isinstance(type_, SignatureType):
                raise TypeError("Invalid type for `type`, type has to be `SignatureType`")

        self._type = type_

    @property
    def key(self):
        # type: () -> string_types
        """Gets the key of this WebhookSignature.

        The key of the signature (required)

        :return: The key of this WebhookSignature.
        :rtype: string_types
        """
        return self._key

    @key.setter
    def key(self, key):
        # type: (string_types) -> None
        """Sets the key of this WebhookSignature.

        The key of the signature (required)

        :param key: The key of this WebhookSignature.
        :type: string_types
        """

        if key is not None:
            if not isinstance(key, string_types):
                raise TypeError("Invalid type for `key`, type has to be `string_types`")

        self._key = key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookSignature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Status(Enum):
    CREATED = "CREATED"
    QUEUED = "QUEUED"
    RUNNING = "RUNNING"
    FINISHED = "FINISHED"
    ERROR = "ERROR"
    CANCELED = "CANCELED"
    TRANSFER_ERROR = "TRANSFER_ERROR"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsExportFileFormat(Enum):
    CSV = "CSV"
    PARQUET = "PARQUET"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class HlsManifestAdMarkerSettings(object):
    @poscheck_model
    def __init__(self,
                 enabled_marker_types=None,
                 disable_preannouncing=None):
        # type: (list[HlsManifestAdMarkerType], bool) -> None

        self._enabled_marker_types = list()
        self._disable_preannouncing = None
        self.discriminator = None

        if enabled_marker_types is not None:
            self.enabled_marker_types = enabled_marker_types
        if disable_preannouncing is not None:
            self.disable_preannouncing = disable_preannouncing

    @property
    def openapi_types(self):
        types = {
            'enabled_marker_types': 'list[HlsManifestAdMarkerType]',
            'disable_preannouncing': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'enabled_marker_types': 'enabledMarkerTypes',
            'disable_preannouncing': 'disablePreannouncing'
        }
        return attributes

    @property
    def enabled_marker_types(self):
        # type: () -> list[HlsManifestAdMarkerType]
        """Gets the enabled_marker_types of this HlsManifestAdMarkerSettings.

        Ad marker types that will be inserted. More than one type is possible.  - EXT_X_CUE_OUT_IN: Ad markers will be inserted using `#EXT-X-CUE-OUT` and `#EXT-X-CUE-IN` tags - EXT_OATCLS_SCTE35: Ad markers will be inserted using `#EXT-OATCLS-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SPLICEPOINT_SCTE35: Ad markers will be inserted using `#EXT-X-SPLICEPOINT-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_DATERANGE: Ad markers will be inserted using `#EXT-X-DATERANGE` tags. They contain the ID, start timestamp and hex encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SCTE35: Ad markers will be inserted using `#EXT-X-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. 

        :return: The enabled_marker_types of this HlsManifestAdMarkerSettings.
        :rtype: list[HlsManifestAdMarkerType]
        """
        return self._enabled_marker_types

    @enabled_marker_types.setter
    def enabled_marker_types(self, enabled_marker_types):
        # type: (list) -> None
        """Sets the enabled_marker_types of this HlsManifestAdMarkerSettings.

        Ad marker types that will be inserted. More than one type is possible.  - EXT_X_CUE_OUT_IN: Ad markers will be inserted using `#EXT-X-CUE-OUT` and `#EXT-X-CUE-IN` tags - EXT_OATCLS_SCTE35: Ad markers will be inserted using `#EXT-OATCLS-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SPLICEPOINT_SCTE35: Ad markers will be inserted using `#EXT-X-SPLICEPOINT-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_DATERANGE: Ad markers will be inserted using `#EXT-X-DATERANGE` tags. They contain the ID, start timestamp and hex encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SCTE35: Ad markers will be inserted using `#EXT-X-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. 

        :param enabled_marker_types: The enabled_marker_types of this HlsManifestAdMarkerSettings.
        :type: list[HlsManifestAdMarkerType]
        """

        if enabled_marker_types is not None:
            if not isinstance(enabled_marker_types, list):
                raise TypeError("Invalid type for `enabled_marker_types`, type has to be `list[HlsManifestAdMarkerType]`")

        self._enabled_marker_types = enabled_marker_types

    @property
    def disable_preannouncing(self):
        # type: () -> bool
        """Gets the disable_preannouncing of this HlsManifestAdMarkerSettings.

        Certain tags, such as EXT_X_DATERANGE, may be preannounced in the HLS manifest. This means they are inserted as early as possible, before the actual ad break begins or ends. Preannouncing helps clients anticipate upcoming splice points, but may cause compatibility issues with some downstream consumers (e.g., AWS MediaTailor SSAI). When this setting is enabled, preannouncing of tags is disabled, and tags are inserted at the segment corresponding to the event's splice time. 

        :return: The disable_preannouncing of this HlsManifestAdMarkerSettings.
        :rtype: bool
        """
        return self._disable_preannouncing

    @disable_preannouncing.setter
    def disable_preannouncing(self, disable_preannouncing):
        # type: (bool) -> None
        """Sets the disable_preannouncing of this HlsManifestAdMarkerSettings.

        Certain tags, such as EXT_X_DATERANGE, may be preannounced in the HLS manifest. This means they are inserted as early as possible, before the actual ad break begins or ends. Preannouncing helps clients anticipate upcoming splice points, but may cause compatibility issues with some downstream consumers (e.g., AWS MediaTailor SSAI). When this setting is enabled, preannouncing of tags is disabled, and tags are inserted at the segment corresponding to the event's splice time. 

        :param disable_preannouncing: The disable_preannouncing of this HlsManifestAdMarkerSettings.
        :type: bool
        """

        if disable_preannouncing is not None:
            if not isinstance(disable_preannouncing, bool):
                raise TypeError("Invalid type for `disable_preannouncing`, type has to be `bool`")

        self._disable_preannouncing = disable_preannouncing

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HlsManifestAdMarkerSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ProgressiveWebmMuxingManifestType(Enum):
    DASH_ON_DEMAND = "DASH_ON_DEMAND"
    NONE = "NONE"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.prewarmed_encoder_pool_schedule import PrewarmedEncoderPoolSchedule
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.schedules.prewarmed_encoder_pool_schedule_list_query_params import PrewarmedEncoderPoolScheduleListQueryParams


class SchedulesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SchedulesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, pool_id, prewarmed_encoder_pool_schedule, **kwargs):
        # type: (string_types, PrewarmedEncoderPoolSchedule, dict) -> PrewarmedEncoderPoolSchedule
        """Create prewarmed encoder pool schedule

        :param pool_id: Id of the scheduled encoder pool
        :type pool_id: string_types, required
        :param prewarmed_encoder_pool_schedule: The prewarmed encoder pool schedule to be created
        :type prewarmed_encoder_pool_schedule: PrewarmedEncoderPoolSchedule, required
        :return: Prewarmed encoder pool schedule
        :rtype: PrewarmedEncoderPoolSchedule
        """

        return self.api_client.post(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}/schedules',
            prewarmed_encoder_pool_schedule,
            path_params={'pool_id': pool_id},
            type=PrewarmedEncoderPoolSchedule,
            **kwargs
        )

    def delete(self, pool_id, schedule_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete prewarmed encoder pool schedule

        :param pool_id: Id of the scheduled encoder pool
        :type pool_id: string_types, required
        :param schedule_id: Id of the prewarmed encoder pool schedule
        :type schedule_id: string_types, required
        :return: Id of the prewarmed encoder pool schedule that was deleted
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}/schedules/{schedule_id}',
            path_params={'pool_id': pool_id, 'schedule_id': schedule_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, pool_id, schedule_id, **kwargs):
        # type: (string_types, string_types, dict) -> PrewarmedEncoderPoolSchedule
        """Prewarmed encoder pool schedule details

        :param pool_id: Id of the scheduled encoder pool
        :type pool_id: string_types, required
        :param schedule_id: Id of the prewarmed encoder pool schedule
        :type schedule_id: string_types, required
        :return: Prewarmed encoder pool schedule
        :rtype: PrewarmedEncoderPoolSchedule
        """

        return self.api_client.get(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}/schedules/{schedule_id}',
            path_params={'pool_id': pool_id, 'schedule_id': schedule_id},
            type=PrewarmedEncoderPoolSchedule,
            **kwargs
        )

    def list(self, pool_id, query_params=None, **kwargs):
        # type: (string_types, PrewarmedEncoderPoolScheduleListQueryParams, dict) -> PrewarmedEncoderPoolSchedule
        """List prewarmed encoder pool schedules

        :param pool_id: Id of the scheduled encoder pool
        :type pool_id: string_types, required
        :param query_params: Query parameters
        :type query_params: PrewarmedEncoderPoolScheduleListQueryParams
        :return: List of prewarmed encoder pool schedules
        :rtype: PrewarmedEncoderPoolSchedule
        """

        return self.api_client.get(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}/schedules',
            path_params={'pool_id': pool_id},
            query_params=query_params,
            pagination_response=True,
            type=PrewarmedEncoderPoolSchedule,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DashRepresentationType(Enum):
    TEMPLATE = "TEMPLATE"
    LIST = "LIST"
    TIMELINE = "TIMELINE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DashRepresentationTypeDiscriminator(Enum):
    DRM_FMP4 = "DRM_FMP4"
    FMP4 = "FMP4"
    WEBM = "WEBM"
    CMAF = "CMAF"
    CHUNKED_TEXT = "CHUNKED_TEXT"
    MP4 = "MP4"
    DRM_MP4 = "DRM_MP4"
    PROGRESSIVE_WEBM = "PROGRESSIVE_WEBM"
    VTT = "VTT"
    SPRITE = "SPRITE"
    IMSC = "IMSC"
    CONTENT_PROTECTION = "CONTENT_PROTECTION"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.external_id_mode import ExternalIdMode
import pprint
import six


class SpekeDrmProvider(object):
    @poscheck_model
    def __init__(self,
                 url=None,
                 username=None,
                 password=None,
                 api_key=None,
                 role_arn=None,
                 external_id=None,
                 external_id_mode=None,
                 gateway_region=None):
        # type: (string_types, string_types, string_types, string_types, string_types, string_types, ExternalIdMode, string_types) -> None

        self._url = None
        self._username = None
        self._password = None
        self._api_key = None
        self._role_arn = None
        self._external_id = None
        self._external_id_mode = None
        self._gateway_region = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if api_key is not None:
            self.api_key = api_key
        if role_arn is not None:
            self.role_arn = role_arn
        if external_id is not None:
            self.external_id = external_id
        if external_id_mode is not None:
            self.external_id_mode = external_id_mode
        if gateway_region is not None:
            self.gateway_region = gateway_region

    @property
    def openapi_types(self):
        types = {
            'url': 'string_types',
            'username': 'string_types',
            'password': 'string_types',
            'api_key': 'string_types',
            'role_arn': 'string_types',
            'external_id': 'string_types',
            'external_id_mode': 'ExternalIdMode',
            'gateway_region': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'url': 'url',
            'username': 'username',
            'password': 'password',
            'api_key': 'apiKey',
            'role_arn': 'roleArn',
            'external_id': 'externalId',
            'external_id_mode': 'externalIdMode',
            'gateway_region': 'gatewayRegion'
        }
        return attributes

    @property
    def url(self):
        # type: () -> string_types
        """Gets the url of this SpekeDrmProvider.

        URL of the endpoint (required)

        :return: The url of this SpekeDrmProvider.
        :rtype: string_types
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (string_types) -> None
        """Sets the url of this SpekeDrmProvider.

        URL of the endpoint (required)

        :param url: The url of this SpekeDrmProvider.
        :type: string_types
        """

        if url is not None:
            if not isinstance(url, string_types):
                raise TypeError("Invalid type for `url`, type has to be `string_types`")

        self._url = url

    @property
    def username(self):
        # type: () -> string_types
        """Gets the username of this SpekeDrmProvider.

        Your username for Basic Authentication

        :return: The username of this SpekeDrmProvider.
        :rtype: string_types
        """
        return self._username

    @username.setter
    def username(self, username):
        # type: (string_types) -> None
        """Sets the username of this SpekeDrmProvider.

        Your username for Basic Authentication

        :param username: The username of this SpekeDrmProvider.
        :type: string_types
        """

        if username is not None:
            if not isinstance(username, string_types):
                raise TypeError("Invalid type for `username`, type has to be `string_types`")

        self._username = username

    @property
    def password(self):
        # type: () -> string_types
        """Gets the password of this SpekeDrmProvider.

        Your password for Basic Authentication

        :return: The password of this SpekeDrmProvider.
        :rtype: string_types
        """
        return self._password

    @password.setter
    def password(self, password):
        # type: (string_types) -> None
        """Sets the password of this SpekeDrmProvider.

        Your password for Basic Authentication

        :param password: The password of this SpekeDrmProvider.
        :type: string_types
        """

        if password is not None:
            if not isinstance(password, string_types):
                raise TypeError("Invalid type for `password`, type has to be `string_types`")

        self._password = password

    @property
    def api_key(self):
        # type: () -> string_types
        """Gets the api_key of this SpekeDrmProvider.

        Your API key for authentication via X-API-Key HTTP Header

        :return: The api_key of this SpekeDrmProvider.
        :rtype: string_types
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        # type: (string_types) -> None
        """Sets the api_key of this SpekeDrmProvider.

        Your API key for authentication via X-API-Key HTTP Header

        :param api_key: The api_key of this SpekeDrmProvider.
        :type: string_types
        """

        if api_key is not None:
            if not isinstance(api_key, string_types):
                raise TypeError("Invalid type for `api_key`, type has to be `string_types`")

        self._api_key = api_key

    @property
    def role_arn(self):
        # type: () -> string_types
        """Gets the role_arn of this SpekeDrmProvider.

        AWS role that will be assumed for the key exchange in case the provider runs on AWS.  During the key exchange the role will be assumed to be able to access the key provider.  This role is to be created in the customer's account and must be granted access to the API Gateway of the SPEKE server. For Bitmovin to be able to assume this role, the following has to be added to the trust policy of the role:  ``` {   \"Effect\": \"Allow\",   \"Principal\": {     \"AWS\": \"arn:aws:iam::630681592166:user/bitmovinCustomerSpekeAccess\"   },   \"Action\": \"sts:AssumeRole\",   \"Condition\": {     \"StringEquals\": {       \"sts:ExternalId\": \"{{externalId}}\"     }   } } ``` It is recommended to also set the {{externalId}} due to security reasons but it can also be ommitted.  Additionally the role needs a policy similar to the following to be able to invoke the API gateway: ``` {   \"Version\": \"2012-10-17\",   \"Statement\": [     {       \"Effect\": \"Allow\",       \"Action\": [         \"execute-api:Invoke\"       ],       \"Resource\": [         \"arn:aws:execute-api:{{region}}:*:*/*/POST/*\"       ]     }   ] } ``` where `{{region}}` is the region of the API gateway (for example `us-west-2`), the same has to be set in the property 'gatewayRegion'. It's also possible to set `{{region}` to `*` to give the role access to all regions. 

        :return: The role_arn of this SpekeDrmProvider.
        :rtype: string_types
        """
        return self._role_arn

    @role_arn.setter
    def role_arn(self, role_arn):
        # type: (string_types) -> None
        """Sets the role_arn of this SpekeDrmProvider.

        AWS role that will be assumed for the key exchange in case the provider runs on AWS.  During the key exchange the role will be assumed to be able to access the key provider.  This role is to be created in the customer's account and must be granted access to the API Gateway of the SPEKE server. For Bitmovin to be able to assume this role, the following has to be added to the trust policy of the role:  ``` {   \"Effect\": \"Allow\",   \"Principal\": {     \"AWS\": \"arn:aws:iam::630681592166:user/bitmovinCustomerSpekeAccess\"   },   \"Action\": \"sts:AssumeRole\",   \"Condition\": {     \"StringEquals\": {       \"sts:ExternalId\": \"{{externalId}}\"     }   } } ``` It is recommended to also set the {{externalId}} due to security reasons but it can also be ommitted.  Additionally the role needs a policy similar to the following to be able to invoke the API gateway: ``` {   \"Version\": \"2012-10-17\",   \"Statement\": [     {       \"Effect\": \"Allow\",       \"Action\": [         \"execute-api:Invoke\"       ],       \"Resource\": [         \"arn:aws:execute-api:{{region}}:*:*/*/POST/*\"       ]     }   ] } ``` where `{{region}}` is the region of the API gateway (for example `us-west-2`), the same has to be set in the property 'gatewayRegion'. It's also possible to set `{{region}` to `*` to give the role access to all regions. 

        :param role_arn: The role_arn of this SpekeDrmProvider.
        :type: string_types
        """

        if role_arn is not None:
            if not isinstance(role_arn, string_types):
                raise TypeError("Invalid type for `role_arn`, type has to be `string_types`")

        self._role_arn = role_arn

    @property
    def external_id(self):
        # type: () -> string_types
        """Gets the external_id of this SpekeDrmProvider.

        External ID used together with the IAM role identified by `roleArn` to assume access to the SPEKE server on AWS. 

        :return: The external_id of this SpekeDrmProvider.
        :rtype: string_types
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        # type: (string_types) -> None
        """Sets the external_id of this SpekeDrmProvider.

        External ID used together with the IAM role identified by `roleArn` to assume access to the SPEKE server on AWS. 

        :param external_id: The external_id of this SpekeDrmProvider.
        :type: string_types
        """

        if external_id is not None:
            if not isinstance(external_id, string_types):
                raise TypeError("Invalid type for `external_id`, type has to be `string_types`")

        self._external_id = external_id

    @property
    def external_id_mode(self):
        # type: () -> ExternalIdMode
        """Gets the external_id_mode of this SpekeDrmProvider.


        :return: The external_id_mode of this SpekeDrmProvider.
        :rtype: ExternalIdMode
        """
        return self._external_id_mode

    @external_id_mode.setter
    def external_id_mode(self, external_id_mode):
        # type: (ExternalIdMode) -> None
        """Sets the external_id_mode of this SpekeDrmProvider.


        :param external_id_mode: The external_id_mode of this SpekeDrmProvider.
        :type: ExternalIdMode
        """

        if external_id_mode is not None:
            if not isinstance(external_id_mode, ExternalIdMode):
                raise TypeError("Invalid type for `external_id_mode`, type has to be `ExternalIdMode`")

        self._external_id_mode = external_id_mode

    @property
    def gateway_region(self):
        # type: () -> string_types
        """Gets the gateway_region of this SpekeDrmProvider.

        Describes the region of the AWS API Gateway that is used to access the SPEKE server. This property is mandatory when setting 'roleArn' and has to indicate in which region the AWS API Gateway is setup. This usually corresponds to the `{{region}}` one sets in the execute-api policy for the role as described in 'roleArn'. 

        :return: The gateway_region of this SpekeDrmProvider.
        :rtype: string_types
        """
        return self._gateway_region

    @gateway_region.setter
    def gateway_region(self, gateway_region):
        # type: (string_types) -> None
        """Sets the gateway_region of this SpekeDrmProvider.

        Describes the region of the AWS API Gateway that is used to access the SPEKE server. This property is mandatory when setting 'roleArn' and has to indicate in which region the AWS API Gateway is setup. This usually corresponds to the `{{region}}` one sets in the execute-api policy for the role as described in 'roleArn'. 

        :param gateway_region: The gateway_region of this SpekeDrmProvider.
        :type: string_types
        """

        if gateway_region is not None:
            if not isinstance(gateway_region, string_types):
                raise TypeError("Invalid type for `gateway_region`, type has to be `string_types`")

        self._gateway_region = gateway_region

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpekeDrmProvider):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.muxing import Muxing
from bitmovin_api_sdk.models.stream_conditions_mode import StreamConditionsMode
import pprint
import six


class PackedAudioMuxing(Muxing):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 streams=None,
                 outputs=None,
                 avg_bitrate=None,
                 min_bitrate=None,
                 max_bitrate=None,
                 ignored_by=None,
                 stream_conditions_mode=None,
                 segment_length=None,
                 segment_naming=None,
                 segment_naming_template=None,
                 start_offset=None,
                 segments_muxed=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[MuxingStream], list[EncodingOutput], int, int, int, list[Ignoring], StreamConditionsMode, float, string_types, string_types, int, int) -> None
        super(PackedAudioMuxing, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, streams=streams, outputs=outputs, avg_bitrate=avg_bitrate, min_bitrate=min_bitrate, max_bitrate=max_bitrate, ignored_by=ignored_by, stream_conditions_mode=stream_conditions_mode)

        self._segment_length = None
        self._segment_naming = None
        self._segment_naming_template = None
        self._start_offset = None
        self._segments_muxed = None
        self.discriminator = None

        if segment_length is not None:
            self.segment_length = segment_length
        if segment_naming is not None:
            self.segment_naming = segment_naming
        if segment_naming_template is not None:
            self.segment_naming_template = segment_naming_template
        if start_offset is not None:
            self.start_offset = start_offset
        if segments_muxed is not None:
            self.segments_muxed = segments_muxed

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(PackedAudioMuxing, self), 'openapi_types'):
            types = getattr(super(PackedAudioMuxing, self), 'openapi_types')

        types.update({
            'segment_length': 'float',
            'segment_naming': 'string_types',
            'segment_naming_template': 'string_types',
            'start_offset': 'int',
            'segments_muxed': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(PackedAudioMuxing, self), 'attribute_map'):
            attributes = getattr(super(PackedAudioMuxing, self), 'attribute_map')

        attributes.update({
            'segment_length': 'segmentLength',
            'segment_naming': 'segmentNaming',
            'segment_naming_template': 'segmentNamingTemplate',
            'start_offset': 'startOffset',
            'segments_muxed': 'segmentsMuxed'
        })
        return attributes

    @property
    def segment_length(self):
        # type: () -> float
        """Gets the segment_length of this PackedAudioMuxing.

        Duration of a segment, given in seconds (required)

        :return: The segment_length of this PackedAudioMuxing.
        :rtype: float
        """
        return self._segment_length

    @segment_length.setter
    def segment_length(self, segment_length):
        # type: (float) -> None
        """Sets the segment_length of this PackedAudioMuxing.

        Duration of a segment, given in seconds (required)

        :param segment_length: The segment_length of this PackedAudioMuxing.
        :type: float
        """

        if segment_length is not None:
            if not isinstance(segment_length, (float, int)):
                raise TypeError("Invalid type for `segment_length`, type has to be `float`")

        self._segment_length = segment_length

    @property
    def segment_naming(self):
        # type: () -> string_types
        """Gets the segment_naming of this PackedAudioMuxing.

        Segment naming policy. The required filename extension depends on the codec (e.g. '.aac' for AAC). Either this or *segmentNamingTemplate* must be set.

        :return: The segment_naming of this PackedAudioMuxing.
        :rtype: string_types
        """
        return self._segment_naming

    @segment_naming.setter
    def segment_naming(self, segment_naming):
        # type: (string_types) -> None
        """Sets the segment_naming of this PackedAudioMuxing.

        Segment naming policy. The required filename extension depends on the codec (e.g. '.aac' for AAC). Either this or *segmentNamingTemplate* must be set.

        :param segment_naming: The segment_naming of this PackedAudioMuxing.
        :type: string_types
        """

        if segment_naming is not None:
            if not isinstance(segment_naming, string_types):
                raise TypeError("Invalid type for `segment_naming`, type has to be `string_types`")

        self._segment_naming = segment_naming

    @property
    def segment_naming_template(self):
        # type: () -> string_types
        """Gets the segment_naming_template of this PackedAudioMuxing.

        Segment naming policy containing one or both of the following placeholders: - '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   on each (re)start of the encoding. The resulting string will be copied to the segmentNaming property.   Intended to avoid re-use of segment names after restarting a live encoding. - '{segment_rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   for each different segment. This is intended to avoid guessing segment URLs by replacing segment numbers.  If segmentNamingTemplate is set, segmentNaming must not be set. The required filename extension depends on the codec (e.g. '.aac' for AAC). 

        :return: The segment_naming_template of this PackedAudioMuxing.
        :rtype: string_types
        """
        return self._segment_naming_template

    @segment_naming_template.setter
    def segment_naming_template(self, segment_naming_template):
        # type: (string_types) -> None
        """Sets the segment_naming_template of this PackedAudioMuxing.

        Segment naming policy containing one or both of the following placeholders: - '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   on each (re)start of the encoding. The resulting string will be copied to the segmentNaming property.   Intended to avoid re-use of segment names after restarting a live encoding. - '{segment_rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   for each different segment. This is intended to avoid guessing segment URLs by replacing segment numbers.  If segmentNamingTemplate is set, segmentNaming must not be set. The required filename extension depends on the codec (e.g. '.aac' for AAC). 

        :param segment_naming_template: The segment_naming_template of this PackedAudioMuxing.
        :type: string_types
        """

        if segment_naming_template is not None:
            if not isinstance(segment_naming_template, string_types):
                raise TypeError("Invalid type for `segment_naming_template`, type has to be `string_types`")

        self._segment_naming_template = segment_naming_template

    @property
    def start_offset(self):
        # type: () -> int
        """Gets the start_offset of this PackedAudioMuxing.

        Offset of MPEG-TS timestamps in seconds. E.g., first packet will start with PTS 900,000 for a 10 seconds offset (90,000 MPEG-TS timescale).

        :return: The start_offset of this PackedAudioMuxing.
        :rtype: int
        """
        return self._start_offset

    @start_offset.setter
    def start_offset(self, start_offset):
        # type: (int) -> None
        """Sets the start_offset of this PackedAudioMuxing.

        Offset of MPEG-TS timestamps in seconds. E.g., first packet will start with PTS 900,000 for a 10 seconds offset (90,000 MPEG-TS timescale).

        :param start_offset: The start_offset of this PackedAudioMuxing.
        :type: int
        """

        if start_offset is not None:
            if not isinstance(start_offset, int):
                raise TypeError("Invalid type for `start_offset`, type has to be `int`")

        self._start_offset = start_offset

    @property
    def segments_muxed(self):
        # type: () -> int
        """Gets the segments_muxed of this PackedAudioMuxing.

        Number of segments which have been encoded

        :return: The segments_muxed of this PackedAudioMuxing.
        :rtype: int
        """
        return self._segments_muxed

    @segments_muxed.setter
    def segments_muxed(self, segments_muxed):
        # type: (int) -> None
        """Sets the segments_muxed of this PackedAudioMuxing.

        Number of segments which have been encoded

        :param segments_muxed: The segments_muxed of this PackedAudioMuxing.
        :type: int
        """

        if segments_muxed is not None:
            if not isinstance(segments_muxed, int):
                raise TypeError("Invalid type for `segments_muxed`, type has to be `int`")

        self._segments_muxed = segments_muxed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(PackedAudioMuxing, self), "to_dict"):
            result = super(PackedAudioMuxing, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackedAudioMuxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.oci_account import OciAccount
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.oci.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.oci.oci_account_list_query_params import OciAccountListQueryParams


class OciApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(OciApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.regions = RegionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, oci_account, **kwargs):
        # type: (OciAccount, dict) -> OciAccount
        """Add OCI account

        :param oci_account: The OCI account to be added
        :type oci_account: OciAccount, required
        :return: OCI account
        :rtype: OciAccount
        """

        return self.api_client.post(
            '/encoding/infrastructure/oci',
            oci_account,
            type=OciAccount,
            **kwargs
        )

    def delete(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> OciAccount
        """Delete OCI account

        :param infrastructure_id: Id of the OCI account
        :type infrastructure_id: string_types, required
        :return: OCI account
        :rtype: OciAccount
        """

        return self.api_client.delete(
            '/encoding/infrastructure/oci/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=OciAccount,
            **kwargs
        )

    def get(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> OciAccount
        """OCI account details

        :param infrastructure_id: Id of the OCI account
        :type infrastructure_id: string_types, required
        :return: OCI account
        :rtype: OciAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/oci/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=OciAccount,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (OciAccountListQueryParams, dict) -> OciAccount
        """List OCI accounts

        :param query_params: Query parameters
        :type query_params: OciAccountListQueryParams
        :return: List of OCI accounts
        :rtype: OciAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/oci',
            query_params=query_params,
            pagination_response=True,
            type=OciAccount,
            **kwargs
        )



from bitmovin_api_sdk.account.organizations.sub_organizations.sub_organizations_api import SubOrganizationsApi
from bitmovin_api_sdk.account.organizations.sub_organizations.organization_list_query_params import OrganizationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ConvertSccPositionMode(Enum):
    FULL = "FULL"
    SIMPLE = "SIMPLE"
    NONE = "NONE"



from bitmovin_api_sdk.common.api_client import ApiClient
from bitmovin_api_sdk.common.base_api import BaseApi
from bitmovin_api_sdk.common.bitmovin_api_logger_base import BitmovinApiLoggerBase
from bitmovin_api_sdk.common.bitmovin_api_logger import BitmovinApiLogger
from bitmovin_api_sdk.common.bitmovin_error import BitmovinError
from bitmovin_api_sdk.common.bitmovin_json_decoder import BitmovinJsonDecoder
from bitmovin_api_sdk.common.rest_client import RestClient



from bitmovin_api_sdk.encoding.encodings.streams.qc.psnr.psnr_api import PsnrApi
from bitmovin_api_sdk.encoding.encodings.streams.qc.psnr.psnr_quality_metric_list_query_params import PsnrQualityMetricListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LiveStandbyPoolEncodingManifestType(Enum):
    DASH = "DASH"
    HLS = "HLS"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class NexGuardWatermarkingType(Enum):
    OTT = "OTT"
    DUPLICATED = "DUPLICATED"
